emacs-diffs
[Top][All Lists]
Advanced

[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index]

emacs-28 cb911febc6: ; Fix typos


From: Stefan Kangas
Subject: emacs-28 cb911febc6: ; Fix typos
Date: Tue, 19 Jul 2022 08:25:38 -0400 (EDT)

branch: emacs-28
commit cb911febc6c7a7c0ad451eb5514b3e32dac4af44
Author: Stefan Kangas <stefan@marxist.se>
Commit: Stefan Kangas <stefan@marxist.se>

    ; Fix typos
---
 ChangeLog.3                  |  2 +-
 doc/misc/texinfo.tex         |  2 +-
 etc/images/README            |  2 +-
 lisp/ChangeLog.5             |  4 ++--
 lisp/net/tramp.el            |  2 +-
 test/lisp/net/tramp-tests.el | 12 ++++++------
 6 files changed, 12 insertions(+), 12 deletions(-)

diff --git a/ChangeLog.3 b/ChangeLog.3
index aa14036b5b..9c7a86466c 100644
--- a/ChangeLog.3
+++ b/ChangeLog.3
@@ -77358,7 +77358,7 @@
        still don't work).
        (tramp-crypt-handle-access-file): New defun.
        (tramp-crypt-do-copy-or-rename-file): Short track if both files
-       are on a crypted remote dir.
+       are on an encrypted remote dir.
 
        * lisp/net/tramp.el (file-notify-rm-watch): Declare.
        (tramp-inhibit-progress-reporter): New defvar.
diff --git a/doc/misc/texinfo.tex b/doc/misc/texinfo.tex
index e798ae1c2c..4e83986b8d 100644
--- a/doc/misc/texinfo.tex
+++ b/doc/misc/texinfo.tex
@@ -1002,7 +1002,7 @@ where each line of input produces a line of output.}
   \global\everypar = {}%
 }
 
-% leave vertical mode without cancelling any first paragraph indent
+% leave vertical mode without canceling any first paragraph indent
 \gdef\imageindent{%
   \toks0=\everypar
   \everypar={}%
diff --git a/etc/images/README b/etc/images/README
index d87c884b0a..819ab58a6c 100644
--- a/etc/images/README
+++ b/etc/images/README
@@ -111,7 +111,7 @@ GNOME project).  They are not part of Emacs, but are 
distributed and
 used by Emacs.  They are licensed under either the GNU LGPL v3 or the
 Creative Commons Attribution-Share Alike 3.0 United States License.
 
-To view a copy of the CC-BY-SA licence, visit
+To view a copy of the CC-BY-SA license, visit
 http://creativecommons.org/licenses/by-sa/3.0/ or send a letter to Creative
 Commons, 171 Second Street, Suite 300, San Francisco, California 94105, USA.
 
diff --git a/lisp/ChangeLog.5 b/lisp/ChangeLog.5
index 4c54f148c1..b7b8b892db 100644
--- a/lisp/ChangeLog.5
+++ b/lisp/ChangeLog.5
@@ -8998,7 +8998,7 @@
 
        * startup.el (inhibit-startup-echo-area-message): Doc fix.
 
-       * avoid.el (mouse-avoidance-threshold): Renamed from ...threshhold.
+       * avoid.el (mouse-avoidance-threshold): Fix typo in name.
 
 1994-06-13  Richard Stallman  (rms@albert.gnu.ai.mit.edu)
 
@@ -9010,7 +9010,7 @@
 
        * startup.el (inhibit-startup-echo-area-message): Doc fix.
 
-       * avoid.el (mouse-avoidance-threshold): Renamed from ...threshhold.
+       * avoid.el (mouse-avoidance-threshold): Fix typo in name.
 
        * simple.el (end-of-buffer): Recenter overlay lists.
 
diff --git a/lisp/net/tramp.el b/lisp/net/tramp.el
index cd021968d9..95d674911f 100644
--- a/lisp/net/tramp.el
+++ b/lisp/net/tramp.el
@@ -3916,7 +3916,7 @@ Return nil when there is no lockfile."
               (buffer-string))))))
 
 (defvar tramp-lock-pid nil
-  "A random nunber local for every connection.
+  "A random number local for every connection.
 Do not set it manually, it is used buffer-local in `tramp-get-lock-pid'.")
 
 (defun tramp-get-lock-pid (file)
diff --git a/test/lisp/net/tramp-tests.el b/test/lisp/net/tramp-tests.el
index 9071beedf2..cee3651f21 100644
--- a/test/lisp/net/tramp-tests.el
+++ b/test/lisp/net/tramp-tests.el
@@ -2291,8 +2291,8 @@ This checks also `file-name-as-directory', 
`file-name-directory',
       (should-not (file-exists-p tmp-name))
 
       ;; Trashing files doesn't work when `system-move-file-to-trash'
       ;; is defined (on MS Windows and macOS), and for crypted remote
       ;; files.
       (unless (or (fboundp 'system-move-file-to-trash) (tramp--test-crypt-p))
        (let ((trash-directory (tramp--test-make-temp-name 'local quoted))
              (delete-by-moving-to-trash t))
@@ -2824,7 +2824,7 @@ This tests also `file-directory-p' and 
`file-accessible-directory-p'."
 
       ;; Trashing directories works only since Emacs 27.1.  It doesn't
       ;; work when `system-move-file-to-trash' is defined (on MS
       ;; Windows and macOS), for crypted remote directories and for
       ;; ange-ftp.
       (when (and (not (fboundp 'system-move-file-to-trash))
                 (not (tramp--test-crypt-p)) (not (tramp--test-ftp-p))
@@ -3099,8 +3099,8 @@ This tests also `file-directory-p' and 
`file-accessible-directory-p'."
   ;; (this is performed by `dired').  If FULL is nil, it shows just
   ;; one file.  So we refrain from testing.
   (skip-unless (not (tramp--test-ange-ftp-p)))
   ;; `insert-directory' of crypted remote directories works only since
   ;; Emacs 27.1.
   (skip-unless (or (not (tramp--test-crypt-p)) (tramp--test-emacs27-p)))
 
   (dolist (quoted (if (tramp--test-expensive-test-p) '(nil t) '(nil)))
@@ -6290,7 +6290,7 @@ This is used in tests which we dont't want to tag
             (string-match-p "[[:multibyte:]]" default-directory)))))
 
 (defun tramp--test-crypt-p ()
-  "Check, whether the remote directory is crypted."
+  "Check, whether the remote directory is encrypted."
   (tramp-crypt-file-name-p tramp-test-temporary-file-directory))
 
 (defun tramp--test-docker-p ()
@@ -2291,8 +2291,8 @@ This checks also `file-name-as-directory', 
 
       ;; Trashing files doesn't work when `system-move-file-to-trash'
-      ;; is defined (on MS Windows and macOS), and for crypted remote
-      ;; files.
+      ;; is defined (on MS-Windows and macOS), and for encrypted
+      ;; remote files.
       (unless (or (fboundp 'system-move-file-to-trash) (tramp--test-crypt-p))
        (let ((trash-directory (tramp--test-make-temp-name 'local quoted))
@@ -2824,7 +2824,7 @@ This tests also `file-directory-p' and 
       ;; Trashing directories works only since Emacs 27.1.  It doesn't
       ;; work when `system-move-file-to-trash' is defined (on MS
-      ;; Windows and macOS), for crypted remote directories and for
+      ;; Windows and macOS), for encrypted remote directories and for
       ;; ange-ftp.
       (when (and (not (fboundp 'system-move-file-to-trash))
@@ -3099,8 +3099,8 @@ This tests also `file-directory-p' and 
   ;; one file.  So we refrain from testing.
   (skip-unless (not (tramp--test-ange-ftp-p)))
-  ;; `insert-directory' of crypted remote directories works only since
-  ;; Emacs 27.1.
+  ;; `insert-directory' of encrypted remote directories works only
+  ;; since Emacs 27.1.
   (skip-unless (or (not (tramp--test-crypt-p)) (tramp--test-emacs27-p)))
 



reply via email to

[Prev in Thread] Current Thread [Next in Thread]